import json

import requests


class ApiConnection(object):
    def __init__(self, url, token_auth):
        self.url = url
        self.token_auth = token_auth

    def get(self, module, method):
        response = requests.get(self.url, params={
            'token_auth': self.token_auth,
            'module': module,
            'method': '{0}.{1}'.format(module, method),
            'format': 'json'
        })

        return response.json()



import datetime
class User(object):

    def __init__(self, login=None, email=None, **kwargs):
        self.login = login
        self.email = email
        self.alias = kwargs.get('alias')
        self.token_auth = kwargs.get('token_auth')
        self.is_superuser = kwargs.get('is_superuser')
        self.date_registered = kwargs.get('date_registered')

    def __eq__(self, other):
        return self.login == other.login

    @classmethod
    def from_dict(cls, data):
        user = User()
        user.login = data['login']
        user.email = data['email']
        user.alias = data['alias']
        user.token_auth = data['token_auth']
        user.is_superuser = int(data['superuser_access']) > 0
        user.date_registered = datetime.datetime.strptime(
            data['date_registered'],
            '%Y-%m-%d %H:%M:%S'
        )

        return user


from .api import ApiConnection
from .user import User


class Server(object):

    __users = None

    @property
    def users(self):
        if self.__users is None:
            self.__users = [
                User.from_dict(u) for u in self._api.get(
                    module='UsersManager',
                    method='getUsers',
                )
            ]

        return self.__users

    __version = None

    @property
    def version(self):
        if self.__version is None:
            self.__version = self._api.get(
                module='API',
                method='getPiwikVersion'
            )['value']

        return self.__version


    def __init__(self, url, token_auth):
        self._api = ApiConnection(url=url, token_auth=token_auth)


from setuptools import setup
import codecs
import os
import re

here = os.path.abspath(os.path.dirname(__file__))


# Read the version number from a source file.
# Why read it, and not import?
# see https://groups.google.com/d/topic/pypa-dev/0PkjVpcxTzQ/discussion
def find_version(*file_paths):
    # Open in Latin-1 so that we avoid encoding errors.
    # Use codecs.open for Python 2 compatibility
    with codecs.open(os.path.join(here, *file_paths), 'r', 'latin1') as f:
        version_file = f.read()

    # The version line must have the form
    # __version__ = 'ver'
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

with open('README.md') as f:
    long_description = f.read()

setup(
    name='pypiwik',
    version=find_version('pypiwik', '__init__.py'),
    description="Python wrapper for the Piwik API",
    long_description=long_description,

    url='http://github.com/pythagorists/pypiwik',

    license='MIT',

    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: PyPy',
        'License :: OSI Approved :: MIT License',
    ],

    keywords='piwik',

    packages=['pypiwik'],

    install_requires=[],
)
